# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/wey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/wey.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1emodules/canbus/proto/wey.proto\x12\rapollo.canbus\"\xdc\x02\n\x0f\x41\x64s_shifter_115\x12G\n\rads_shiftmode\x18\x01 \x01(\x0e\x32\x30.apollo.canbus.Ads_shifter_115.Ads_shiftmodeType\x12I\n\x0e\x61\x64s_targetgear\x18\x02 \x01(\x0e\x32\x31.apollo.canbus.Ads_shifter_115.Ads_targetgearType\"G\n\x11\x41\x64s_shiftmodeType\x12\x19\n\x15\x41\x44S_SHIFTMODE_INVALID\x10\x00\x12\x17\n\x13\x41\x44S_SHIFTMODE_VALID\x10\x01\"l\n\x12\x41\x64s_targetgearType\x12\x14\n\x10\x41\x44S_TARGETGEAR_N\x10\x00\x12\x14\n\x10\x41\x44S_TARGETGEAR_R\x10\x01\x12\x14\n\x10\x41\x44S_TARGETGEAR_P\x10\x02\x12\x14\n\x10\x41\x44S_TARGETGEAR_D\x10\x03\"\xb1\x01\n\x0b\x41\x64s_eps_113\x12?\n\x0b\x61\x64s_epsmode\x18\x01 \x01(\x0e\x32*.apollo.canbus.Ads_eps_113.Ads_epsmodeType\x12\x1d\n\x15\x61\x64s_reqepstargetangle\x18\x02 \x01(\x01\"B\n\x0f\x41\x64s_epsmodeType\x12\x17\n\x13\x41\x44S_EPSMODE_DISABLE\x10\x00\x12\x16\n\x12\x41\x44S_EPSMODE_ACTIVE\x10\x02\"\x93+\n\nStatus_310\x12J\n\x11longitudeaccvalid\x18\x01 \x01(\x0e\x32/.apollo.canbus.Status_310.LongitudeaccvalidType\x12H\n\x10lateralaccevalid\x18\x02 \x01(\x0e\x32..apollo.canbus.Status_310.LateralaccevalidType\x12L\n\x12vehdynyawratevalid\x18\x03 \x01(\x0e\x32\x30.apollo.canbus.Status_310.VehdynyawratevalidType\x12\x46\n\x0f\x66lwheelspdvalid\x18\x04 \x01(\x0e\x32-.apollo.canbus.Status_310.FlwheelspdvalidType\x12\x46\n\x0f\x66rwheelspdvalid\x18\x05 \x01(\x0e\x32-.apollo.canbus.Status_310.FrwheelspdvalidType\x12\x46\n\x0frlwheelspdvalid\x18\x06 \x01(\x0e\x32-.apollo.canbus.Status_310.RlwheelspdvalidType\x12\x46\n\x0frrwheelspdvalid\x18\x07 \x01(\x0e\x32-.apollo.canbus.Status_310.RrwheelspdvalidType\x12\x46\n\x0fvehiclespdvalid\x18\x08 \x01(\x0e\x32-.apollo.canbus.Status_310.VehiclespdvalidType\x12P\n\x14longitudedrivingmode\x18\t \x01(\x0e\x32\x32.apollo.canbus.Status_310.LongitudedrivingmodeType\x12>\n\x0b\x65ngspdvalid\x18\n \x01(\x0e\x32).apollo.canbus.Status_310.EngspdvalidType\x12J\n\x11\x61\x63\x63\x65pedaloverride\x18\x0b \x01(\x0e\x32/.apollo.canbus.Status_310.AccepedaloverrideType\x12H\n\x10\x62rakepedalstatus\x18\x0c \x01(\x0e\x32..apollo.canbus.Status_310.BrakepedalstatusType\x12H\n\x10\x65spbrakelightsts\x18\r \x01(\x0e\x32..apollo.canbus.Status_310.EspbrakelightstsType\x12N\n\x13\x65pbswtpositionvalid\x18\x0e \x01(\x0e\x32\x31.apollo.canbus.Status_310.EpbswtpositionvalidType\x12\x34\n\x06\x65pbsts\x18\x0f \x01(\x0e\x32$.apollo.canbus.Status_310.EpbstsType\x12H\n\x10\x63urrentgearvalid\x18\x10 \x01(\x0e\x32..apollo.canbus.Status_310.CurrentgearvalidType\x12\x42\n\repstrqsnsrsts\x18\x11 \x01(\x0e\x32+.apollo.canbus.Status_310.EpstrqsnsrstsType\x12R\n\x15\x65ps_interferdetdvalid\x18\x12 \x01(\x0e\x32\x33.apollo.canbus.Status_310.Eps_interferdetdvalidType\x12\x46\n\x0f\x65pshandsdetnsts\x18\x13 \x01(\x0e\x32-.apollo.canbus.Status_310.EpshandsdetnstsType\x12R\n\x15\x65ps_handsdetnstsvalid\x18\x14 \x01(\x0e\x32\x33.apollo.canbus.Status_310.Eps_handsdetnstsvalidType\x12N\n\x13steerwheelanglesign\x18\x15 \x01(\x0e\x32\x31.apollo.canbus.Status_310.SteerwheelanglesignType\x12J\n\x11steerwheelspdsign\x18\x16 \x01(\x0e\x32/.apollo.canbus.Status_310.SteerwheelspdsignType\x12\x42\n\rdriverdoorsts\x18\x17 \x01(\x0e\x32+.apollo.canbus.Status_310.DriverdoorstsType\x12:\n\trldoorsts\x18\x18 \x01(\x0e\x32\'.apollo.canbus.Status_310.RldoorstsType\x12H\n\x10passengerdoorsts\x18\x19 \x01(\x0e\x32..apollo.canbus.Status_310.PassengerdoorstsType\x12:\n\trrdoorsts\x18\x1a \x01(\x0e\x32\'.apollo.canbus.Status_310.RrdoorstsType\x12\x44\n\x0e\x66rontfoglmpsts\x18\x1b \x01(\x0e\x32,.apollo.canbus.Status_310.FrontfoglmpstsType\x12\x42\n\rrearfoglmpsts\x18\x1c \x01(\x0e\x32+.apollo.canbus.Status_310.RearfoglmpstsType\x12<\n\nlowbeamsts\x18\x1d \x01(\x0e\x32(.apollo.canbus.Status_310.LowbeamstsType\x12>\n\x0bhighbeamsts\x18\x1e \x01(\x0e\x32).apollo.canbus.Status_310.HighbeamstsType\x12\x46\n\x0fleftturnlampsts\x18\x1f \x01(\x0e\x32-.apollo.canbus.Status_310.LeftturnlampstsType\x12H\n\x10rightturnlampsts\x18  \x01(\x0e\x32..apollo.canbus.Status_310.RightturnlampstsType\x12@\n\x0c\x62\x63m_availsts\x18! \x01(\x0e\x32*.apollo.canbus.Status_310.Bcm_availstsType\x12>\n\x0b\x62rakelmpsts\x18\" \x01(\x0e\x32).apollo.canbus.Status_310.BrakelmpstsType\"S\n\x15LongitudeaccvalidType\x12\x1d\n\x19LONGITUDEACCVALID_INVALID\x10\x00\x12\x1b\n\x17LONGITUDEACCVALID_VALID\x10\x01\"P\n\x14LateralaccevalidType\x12\x1c\n\x18LATERALACCEVALID_INVALID\x10\x00\x12\x1a\n\x16LATERALACCEVALID_VALID\x10\x01\"V\n\x16VehdynyawratevalidType\x12\x1e\n\x1aVEHDYNYAWRATEVALID_INVALID\x10\x00\x12\x1c\n\x18VEHDYNYAWRATEVALID_VALID\x10\x01\"M\n\x13\x46lwheelspdvalidType\x12\x1b\n\x17\x46LWHEELSPDVALID_INVALID\x10\x00\x12\x19\n\x15\x46LWHEELSPDVALID_VALID\x10\x01\"M\n\x13\x46rwheelspdvalidType\x12\x1b\n\x17\x46RWHEELSPDVALID_INVALID\x10\x00\x12\x19\n\x15\x46RWHEELSPDVALID_VALID\x10\x01\"M\n\x13RlwheelspdvalidType\x12\x1b\n\x17RLWHEELSPDVALID_INVALID\x10\x00\x12\x19\n\x15RLWHEELSPDVALID_VALID\x10\x01\"M\n\x13RrwheelspdvalidType\x12\x1b\n\x17RRWHEELSPDVALID_INVALID\x10\x00\x12\x19\n\x15RRWHEELSPDVALID_VALID\x10\x01\"M\n\x13VehiclespdvalidType\x12\x1b\n\x17VEHICLESPDVALID_INVALID\x10\x00\x12\x19\n\x15VEHICLESPDVALID_VALID\x10\x01\"\xca\x01\n\x18LongitudedrivingmodeType\x12#\n\x1fLONGITUDEDRIVINGMODE_MANUALMODE\x10\x00\x12)\n%LONGITUDEDRIVINGMODE_AUTOMATICSTANDBY\x10\x01\x12.\n*LONGITUDEDRIVINGMODE_AUTOMATICACCELERATION\x10\x02\x12.\n*LONGITUDEDRIVINGMODE_AUTOMATICDECELERATION\x10\x03\"w\n\x0f\x45ngspdvalidType\x12\x17\n\x13\x45NGSPDVALID_INVALID\x10\x00\x12\x15\n\x11\x45NGSPDVALID_VALID\x10\x01\x12\x1a\n\x16\x45NGSPDVALID_INIT_VALUE\x10\x02\x12\x18\n\x14\x45NGSPDVALID_RESERVED\x10\x03\"[\n\x15\x41\x63\x63\x65pedaloverrideType\x12\"\n\x1e\x41\x43\x43\x45PEDALOVERRIDE_NOT_OVERRIDE\x10\x00\x12\x1e\n\x1a\x41\x43\x43\x45PEDALOVERRIDE_OVERRIDE\x10\x01\"\x92\x01\n\x14\x42rakepedalstatusType\x12 \n\x1c\x42RAKEPEDALSTATUS_NOT_PRESSED\x10\x00\x12\x1c\n\x18\x42RAKEPEDALSTATUS_PRESSED\x10\x01\x12\x1e\n\x1a\x42RAKEPEDALSTATUS_RESERVED1\x10\x02\x12\x1a\n\x16\x42RAKEPEDALSTATUS_ERROR\x10\x03\"I\n\x14\x45spbrakelightstsType\x12\x18\n\x14\x45SPBRAKELIGHTSTS_OFF\x10\x00\x12\x17\n\x13\x45SPBRAKELIGHTSTS_ON\x10\x01\"[\n\x17\x45pbswtpositionvalidType\x12\x1d\n\x19\x45PBSWTPOSITIONVALID_VALID\x10\x00\x12!\n\x1d\x45PBSWTPOSITIONVALID_NOT_VALID\x10\x01\"`\n\nEpbstsType\x12\x13\n\x0f\x45PBSTS_RELEASED\x10\x00\x12\x11\n\rEPBSTS_CLOSED\x10\x01\x12\x16\n\x12\x45PBSTS_IN_PROGRESS\x10\x02\x12\x12\n\x0e\x45PBSTS_UNKNOWN\x10\x03\"P\n\x14\x43urrentgearvalidType\x12\x1c\n\x18\x43URRENTGEARVALID_INVALID\x10\x00\x12\x1a\n\x16\x43URRENTGEARVALID_VALID\x10\x01\"I\n\x11\x45pstrqsnsrstsType\x12\x18\n\x14\x45PSTRQSNSRSTS_NORMAL\x10\x00\x12\x1a\n\x16\x45PSTRQSNSRSTS_ABNORMAL\x10\x01\"_\n\x19\x45ps_interferdetdvalidType\x12!\n\x1d\x45PS_INTERFERDETDVALID_INVALID\x10\x00\x12\x1f\n\x1b\x45PS_INTERFERDETDVALID_VALID\x10\x01\"g\n\x13\x45pshandsdetnstsType\x12)\n%EPSHANDSDETNSTS_HANDSOFF_NOT_DETECTED\x10\x00\x12%\n!EPSHANDSDETNSTS_HANDOFFF_DETECTED\x10\x01\"_\n\x19\x45ps_handsdetnstsvalidType\x12!\n\x1d\x45PS_HANDSDETNSTSVALID_INVALID\x10\x00\x12\x1f\n\x1b\x45PS_HANDSDETNSTSVALID_VALID\x10\x01\"h\n\x17SteerwheelanglesignType\x12%\n!STEERWHEELANGLESIGN_LEFT_POSITIVE\x10\x00\x12&\n\"STEERWHEELANGLESIGN_RIGHT_NEGATIVE\x10\x01\"b\n\x15SteerwheelspdsignType\x12#\n\x1fSTEERWHEELSPDSIGN_LEFT_POSITIVE\x10\x00\x12$\n STEERWHEELSPDSIGN_RIGHT_NEGATIVE\x10\x01\"E\n\x11\x44riverdoorstsType\x12\x18\n\x14\x44RIVERDOORSTS_CLOSED\x10\x00\x12\x16\n\x12\x44RIVERDOORSTS_OPEN\x10\x01\"9\n\rRldoorstsType\x12\x14\n\x10RLDOORSTS_CLOSED\x10\x00\x12\x12\n\x0eRLDOORSTS_OPEN\x10\x01\"N\n\x14PassengerdoorstsType\x12\x1b\n\x17PASSENGERDOORSTS_CLOSED\x10\x00\x12\x19\n\x15PASSENGERDOORSTS_OPEN\x10\x01\"9\n\rRrdoorstsType\x12\x14\n\x10RRDOORSTS_CLOSED\x10\x00\x12\x12\n\x0eRRDOORSTS_OPEN\x10\x01\"\x82\x01\n\x12\x46rontfoglmpstsType\x12\x16\n\x12\x46RONTFOGLMPSTS_OFF\x10\x00\x12\x15\n\x11\x46RONTFOGLMPSTS_ON\x10\x01\x12\x1b\n\x17\x46RONTFOGLMPSTS_RESERVED\x10\x02\x12 \n\x1c\x46RONTFOGLMPSTS_NOT_AVAILABLE\x10\x03\"@\n\x11RearfoglmpstsType\x12\x15\n\x11REARFOGLMPSTS_OFF\x10\x00\x12\x14\n\x10REARFOGLMPSTS_ON\x10\x01\"7\n\x0eLowbeamstsType\x12\x12\n\x0eLOWBEAMSTS_OFF\x10\x00\x12\x11\n\rLOWBEAMSTS_ON\x10\x01\":\n\x0fHighbeamstsType\x12\x13\n\x0fHIGHBEAMSTS_OFF\x10\x00\x12\x12\n\x0eHIGHBEAMSTS_ON\x10\x01\"F\n\x13LeftturnlampstsType\x12\x17\n\x13LEFTTURNLAMPSTS_OFF\x10\x00\x12\x16\n\x12LEFTTURNLAMPSTS_ON\x10\x01\"I\n\x14RightturnlampstsType\x12\x18\n\x14RIGHTTURNLAMPSTS_OFF\x10\x00\x12\x17\n\x13RIGHTTURNLAMPSTS_ON\x10\x01\"\x8a\x01\n\x10\x42\x63m_availstsType\x12\x1c\n\x18\x42\x43M_AVAILSTS_MANUAL_MODE\x10\x00\x12 \n\x1c\x42\x43M_AVAILSTS_AUTONOMOUS_MODE\x10\x01\x12\x1a\n\x16\x42\x43M_AVAILSTS_RESERVED1\x10\x02\x12\x1a\n\x16\x42\x43M_AVAILSTS_RESERVED2\x10\x03\":\n\x0f\x42rakelmpstsType\x12\x13\n\x0f\x42RAKELMPSTS_OFF\x10\x00\x12\x12\n\x0e\x42RAKELMPSTS_ON\x10\x01\"\x1e\n\rVin_resp3_393\x12\r\n\x05vin16\x18\x01 \x01(\x05\"\x87\x01\n\rVin_resp2_392\x12\r\n\x05vin15\x18\x01 \x01(\x05\x12\r\n\x05vin14\x18\x02 \x01(\x05\x12\r\n\x05vin13\x18\x03 \x01(\x05\x12\r\n\x05vin12\x18\x04 \x01(\x05\x12\r\n\x05vin11\x18\x05 \x01(\x05\x12\r\n\x05vin10\x18\x06 \x01(\x05\x12\r\n\x05vin09\x18\x07 \x01(\x05\x12\r\n\x05vin08\x18\x08 \x01(\x05\"\x87\x01\n\rVin_resp1_391\x12\r\n\x05vin07\x18\x01 \x01(\x05\x12\r\n\x05vin06\x18\x02 \x01(\x05\x12\r\n\x05vin05\x18\x03 \x01(\x05\x12\r\n\x05vin04\x18\x04 \x01(\x05\x12\r\n\x05vin03\x18\x05 \x01(\x05\x12\r\n\x05vin02\x18\x06 \x01(\x05\x12\r\n\x05vin00\x18\x07 \x01(\x05\x12\r\n\x05vin01\x18\x08 \x01(\x05\"\xad\x01\n\x0f\x41\x64s_req_vin_390\x12I\n\x0ereq_vin_signal\x18\x01 \x01(\x0e\x32\x31.apollo.canbus.Ads_req_vin_390.Req_vin_signalType\"O\n\x12Req_vin_signalType\x12\x1d\n\x19REQ_VIN_SIGNAL_NO_REQUEST\x10\x00\x12\x1a\n\x16REQ_VIN_SIGNAL_REQUEST\x10\x01\"\x8d\x05\n\x08\x41\x64s1_111\x12@\n\rads_dectostop\x18\x01 \x01(\x0e\x32).apollo.canbus.Ads1_111.Ads_dectostopType\x12\x36\n\x08\x61\x64s_mode\x18\x02 \x01(\x0e\x32$.apollo.canbus.Ads1_111.Ads_modeType\x12\x13\n\x0b\x61\x64s_taracce\x18\x03 \x01(\x01\x12\x46\n\x10\x61\x64s_driveoff_req\x18\x04 \x01(\x0e\x32,.apollo.canbus.Ads1_111.Ads_driveoff_reqType\x12\x17\n\x0f\x61\x64s_aeb_taracce\x18\x05 \x01(\x01\x12N\n\x14\x61\x64s_aeb_tgtdecel_req\x18\x06 \x01(\x0e\x32\x30.apollo.canbus.Ads1_111.Ads_aeb_tgtdecel_reqType\"J\n\x11\x41\x64s_dectostopType\x12\x1b\n\x17\x41\x44S_DECTOSTOP_NO_DEMAND\x10\x00\x12\x18\n\x14\x41\x44S_DECTOSTOP_DEMAND\x10\x01\"?\n\x0c\x41\x64s_modeType\x12\x15\n\x11\x41\x44S_MODE_OFF_MODE\x10\x00\x12\x18\n\x14\x41\x44S_MODE_ACTIVE_MODE\x10\x03\"S\n\x14\x41\x64s_driveoff_reqType\x12\x1e\n\x1a\x41\x44S_DRIVEOFF_REQ_NO_DEMAND\x10\x00\x12\x1b\n\x17\x41\x44S_DRIVEOFF_REQ_DEMAND\x10\x01\"_\n\x18\x41\x64s_aeb_tgtdecel_reqType\x12\"\n\x1e\x41\x44S_AEB_TGTDECEL_REQ_NO_DEMAND\x10\x00\x12\x1f\n\x1b\x41\x44S_AEB_TGTDECEL_REQ_DEMAND\x10\x01\"\x82\x06\n\x08\x46\x62s2_240\x12\x46\n\x10\x66lwheeldirection\x18\x01 \x01(\x0e\x32,.apollo.canbus.Fbs2_240.FlwheeldirectionType\x12\x12\n\nfrwheelspd\x18\x02 \x01(\x01\x12P\n\x15rlwheeldrivedirection\x18\x03 \x01(\x0e\x32\x31.apollo.canbus.Fbs2_240.RlwheeldrivedirectionType\x12\x12\n\nrlwheelspd\x18\x04 \x01(\x01\x12\x46\n\x10rrwheeldirection\x18\x05 \x01(\x0e\x32,.apollo.canbus.Fbs2_240.RrwheeldirectionType\x12\x12\n\nrrwheelspd\x18\x06 \x01(\x01\x12\x12\n\nvehiclespd\x18\x07 \x01(\x01\"\x8c\x01\n\x14\x46lwheeldirectionType\x12\x1c\n\x18\x46LWHEELDIRECTION_INVALID\x10\x00\x12\x1c\n\x18\x46LWHEELDIRECTION_FORWARD\x10\x01\x12\x1d\n\x19\x46LWHEELDIRECTION_BACKWARD\x10\x02\x12\x19\n\x15\x46LWHEELDIRECTION_STOP\x10\x03\"\xa5\x01\n\x19RlwheeldrivedirectionType\x12!\n\x1dRLWHEELDRIVEDIRECTION_INVALID\x10\x00\x12!\n\x1dRLWHEELDRIVEDIRECTION_FORWARD\x10\x01\x12\"\n\x1eRLWHEELDRIVEDIRECTION_BACKWARD\x10\x02\x12\x1e\n\x1aRLWHEELDRIVEDIRECTION_STOP\x10\x03\"\x8c\x01\n\x14RrwheeldirectionType\x12\x1c\n\x18RRWHEELDIRECTION_INVALID\x10\x00\x12\x1c\n\x18RRWHEELDIRECTION_FORWARD\x10\x01\x12\x1d\n\x19RRWHEELDIRECTION_BACKWARD\x10\x02\x12\x19\n\x15RRWHEELDIRECTION_STOP\x10\x03\"\xb8\x02\n\x08\x46\x62s1_243\x12\x15\n\rlongitudeacce\x18\x01 \x01(\x01\x12\x13\n\x0blateralacce\x18\x02 \x01(\x01\x12\x15\n\rvehdynyawrate\x18\x03 \x01(\x01\x12\x12\n\nflwheelspd\x18\x04 \x01(\x01\x12\x46\n\x10\x66rwheeldirection\x18\x05 \x01(\x0e\x32,.apollo.canbus.Fbs1_243.FrwheeldirectionType\"\x8c\x01\n\x14\x46rwheeldirectionType\x12\x1c\n\x18\x46RWHEELDIRECTION_INVALID\x10\x00\x12\x1c\n\x18\x46RWHEELDIRECTION_FORWARD\x10\x01\x12\x1d\n\x19\x46RWHEELDIRECTION_BACKWARD\x10\x02\x12\x19\n\x15\x46RWHEELDIRECTION_STOP\x10\x03\":\n\x08\x46\x62s4_235\x12\x17\n\x0fsteerwheelangle\x18\x01 \x01(\x01\x12\x15\n\rsteerwheelspd\x18\x02 \x01(\x01\"\xa1\x06\n\x08\x46\x61il_241\x12\x34\n\x07\x65ngfail\x18\x01 \x01(\x0e\x32#.apollo.canbus.Fail_241.EngfailType\x12\x34\n\x07\x65spfail\x18\x02 \x01(\x0e\x32#.apollo.canbus.Fail_241.EspfailType\x12\x34\n\x07\x65pbfail\x18\x03 \x01(\x0e\x32#.apollo.canbus.Fail_241.EpbfailType\x12\x38\n\tshiftfail\x18\x04 \x01(\x0e\x32%.apollo.canbus.Fail_241.ShiftfailType\x12\x34\n\x07\x65psfail\x18\x05 \x01(\x0e\x32#.apollo.canbus.Fail_241.EpsfailType\"4\n\x0b\x45ngfailType\x12\x13\n\x0f\x45NGFAIL_NO_FAIL\x10\x00\x12\x10\n\x0c\x45NGFAIL_FAIL\x10\x01\":\n\x0b\x45spfailType\x12\x16\n\x12\x45SPFAIL_NO_FAILURE\x10\x00\x12\x13\n\x0f\x45SPFAIL_FAILURE\x10\x01\"d\n\x0b\x45pbfailType\x12\x15\n\x11\x45PBFAIL_UNDEFINED\x10\x00\x12\x14\n\x10\x45PBFAIL_NO_ERROR\x10\x01\x12\x11\n\rEPBFAIL_ERROR\x10\x02\x12\x15\n\x11\x45PBFAIL_DIAGNOSIS\x10\x03\"\xf2\x01\n\rShiftfailType\x12\x15\n\x11SHIFTFAIL_NO_FAIL\x10\x00\x12&\n\"SHIFTFAIL_TRANSMISSION_MALFUNCTION\x10\x01\x12-\n)SHIFTFAIL_TRANSMISSION_P_ENGAGEMENT_FAULT\x10\x02\x12\x30\n,SHIFTFAIL_TRANSMISSION_P_DISENGAGEMENT_FAULT\x10\x03\x12\x16\n\x12SHIFTFAIL_RESERVED\x10\x04\x12)\n%SHIFTFAIL_TRANSMISSION_LIMIT_FUNCTION\x10\x0f\"6\n\x0b\x45psfailType\x12\x14\n\x10\x45PSFAIL_NO_FAULT\x10\x00\x12\x11\n\rEPSFAIL_FAULT\x10\x01\"\x9e\t\n\x08\x46\x62s3_237\x12\x0e\n\x06\x65ngspd\x18\x01 \x01(\x01\x12\x13\n\x0b\x61\x63\x63pedalpos\x18\x02 \x01(\x01\x12H\n\x11\x65pbswtichposition\x18\x03 \x01(\x0e\x32-.apollo.canbus.Fbs3_237.EpbswtichpositionType\x12<\n\x0b\x63urrentgear\x18\x04 \x01(\x0e\x32\'.apollo.canbus.Fbs3_237.CurrentgearType\x12\x46\n\x10\x65ps_streeingmode\x18\x05 \x01(\x0e\x32,.apollo.canbus.Fbs3_237.Eps_streeingmodeType\x12\x1b\n\x13\x65psdrvinputtrqvalue\x18\x06 \x01(\x01\x12\x1c\n\x14\x65psconsumedcurrvalue\x18\x07 \x01(\x01\x12:\n\nepscurrmod\x18\x08 \x01(\x0e\x32&.apollo.canbus.Fbs3_237.EpscurrmodType\"\x93\x01\n\x15\x45pbswtichpositionType\x12\x1d\n\x19\x45PBSWTICHPOSITION_NEUTRAL\x10\x00\x12\x1d\n\x19\x45PBSWTICHPOSITION_RELEASE\x10\x01\x12\x1b\n\x17\x45PBSWTICHPOSITION_APPLY\x10\x02\x12\x1f\n\x1b\x45PBSWTICHPOSITION_RESERVED1\x10\x03\"]\n\x0f\x43urrentgearType\x12\x11\n\rCURRENTGEAR_P\x10\x00\x12\x11\n\rCURRENTGEAR_R\x10\x01\x12\x11\n\rCURRENTGEAR_N\x10\x02\x12\x11\n\rCURRENTGEAR_D\x10\x03\"\xca\x02\n\x14\x45ps_streeingmodeType\x12\x1b\n\x17\x45PS_STREEINGMODE_MANUAL\x10\x00\x12$\n EPS_STREEINGMODE_AUTOMATIC_AVAIL\x10\x01\x12/\n+EPS_STREEINGMODE_MANUAL_FROM_DRVNTERFERENCE\x10\x02\x12\x34\n0EPS_STREEINGMODE_MANUAL_FROM_EPS_FAILED_DETECTED\x10\x03\x12(\n$EPS_STREEINGMODE_TEMPORARY_INHIBITED\x10\x04\x12\x1e\n\x1a\x45PS_STREEINGMODE_RESERVED1\x10\x05\x12\x1e\n\x1a\x45PS_STREEINGMODE_RESERVED2\x10\x06\x12\x1e\n\x1a\x45PS_STREEINGMODE_RESERVED3\x10\x07\"\xe3\x01\n\x0e\x45pscurrmodType\x12\x1a\n\x16\x45PSCURRMOD_NORMAL_MODE\x10\x00\x12\x19\n\x15\x45PSCURRMOD_SPORT_MODE\x10\x01\x12\x1b\n\x17\x45PSCURRMOD_COMFORT_MODE\x10\x02\x12\'\n#EPSCURRMOD_MODESELECTIONNOTPOSSIBLE\x10\x03\x12\x19\n\x15\x45PSCURRMOD_NO_DISPLAY\x10\x04\x12\x1f\n\x1b\x45PSCURRMOD_CONDITIONNOTMEET\x10\x05\x12\x18\n\x14\x45PSCURRMOD_RESERVED1\x10\x06\"\xbc\x0f\n\x08\x41\x64s3_38e\x12\x44\n\x0f\x61\x64s_bcm_worksts\x18\x01 \x01(\x0e\x32+.apollo.canbus.Ads3_38e.Ads_bcm_workstsType\x12L\n\x13\x61\x64s_bcmworkstsvalid\x18\x02 \x01(\x0e\x32/.apollo.canbus.Ads3_38e.Ads_bcmworkstsvalidType\x12H\n\x11\x61\x64s_reqcontrolbcm\x18\x03 \x01(\x0e\x32-.apollo.canbus.Ads3_38e.Ads_reqcontrolbcmType\x12<\n\x0bhighbeamton\x18\x04 \x01(\x0e\x32\'.apollo.canbus.Ads3_38e.HighbeamtonType\x12>\n\x0c\x64ippedbeamon\x18\x05 \x01(\x0e\x32(.apollo.canbus.Ads3_38e.DippedbeamonType\x12>\n\x0cturnllighton\x18\x06 \x01(\x0e\x32(.apollo.canbus.Ads3_38e.TurnllightonType\x12\x46\n\x10\x65mergencylighton\x18\x07 \x01(\x0e\x32,.apollo.canbus.Ads3_38e.EmergencylightonType\x12:\n\nffoglampon\x18\x08 \x01(\x0e\x32&.apollo.canbus.Ads3_38e.FfoglamponType\x12:\n\nrfoglampon\x18\t \x01(\x0e\x32&.apollo.canbus.Ads3_38e.RfoglamponType\x12:\n\nbrakelight\x18\n \x01(\x0e\x32&.apollo.canbus.Ads3_38e.BrakelightType\x12\x32\n\x06hornon\x18\x0b \x01(\x0e\x32\".apollo.canbus.Ads3_38e.HornonType\x12\x46\n\x10\x66windshieldwiper\x18\x0c \x01(\x0e\x32,.apollo.canbus.Ads3_38e.FwindshieldwiperType\x12\x46\n\x10rwindshieldwiper\x18\r \x01(\x0e\x32,.apollo.canbus.Ads3_38e.RwindshieldwiperType\"\x86\x01\n\x13\x41\x64s_bcm_workstsType\x12\x1b\n\x17\x41\x44S_BCM_WORKSTS_DISABLE\x10\x00\x12\x1a\n\x16\x41\x44S_BCM_WORKSTS_ENABLE\x10\x01\x12\x1a\n\x16\x41\x44S_BCM_WORKSTS_ACTIVE\x10\x02\x12\x1a\n\x16\x41\x44S_BCM_WORKSTS_FAILED\x10\x03\"Y\n\x17\x41\x64s_bcmworkstsvalidType\x12\x1f\n\x1b\x41\x44S_BCMWORKSTSVALID_INVALID\x10\x00\x12\x1d\n\x19\x41\x44S_BCMWORKSTSVALID_VALID\x10\x01\"X\n\x15\x41\x64s_reqcontrolbcmType\x12 \n\x1c\x41\x44S_REQCONTROLBCM_NO_REQUEST\x10\x00\x12\x1d\n\x19\x41\x44S_REQCONTROLBCM_REQUEST\x10\x01\"D\n\x0fHighbeamtonType\x12\x18\n\x14HIGHBEAMTON_TURN_OFF\x10\x00\x12\x17\n\x13HIGHBEAMTON_TURN_ON\x10\x01\"G\n\x10\x44ippedbeamonType\x12\x19\n\x15\x44IPPEDBEAMON_TURN_OFF\x10\x00\x12\x18\n\x14\x44IPPEDBEAMON_TURN_ON\x10\x01\"\x87\x01\n\x10TurnllightonType\x12\x19\n\x15TURNLLIGHTON_TURN_OFF\x10\x00\x12\x1d\n\x19TURNLLIGHTON_TURN_LEFT_ON\x10\x01\x12\x1e\n\x1aTURNLLIGHTON_TURN_RIGHT_ON\x10\x02\x12\x19\n\x15TURNLLIGHTON_RESERVED\x10\x03\"S\n\x14\x45mergencylightonType\x12\x1d\n\x19\x45MERGENCYLIGHTON_TURN_OFF\x10\x00\x12\x1c\n\x18\x45MERGENCYLIGHTON_TURN_ON\x10\x01\"A\n\x0e\x46\x66oglamponType\x12\x17\n\x13\x46\x46OGLAMPON_TURN_OFF\x10\x00\x12\x16\n\x12\x46\x46OGLAMPON_TURN_ON\x10\x01\"A\n\x0eRfoglamponType\x12\x17\n\x13RFOGLAMPON_TURN_OFF\x10\x00\x12\x16\n\x12RFOGLAMPON_TURN_ON\x10\x01\"A\n\x0e\x42rakelightType\x12\x17\n\x13\x42RAKELIGHT_TURN_OFF\x10\x00\x12\x16\n\x12\x42RAKELIGHT_TURN_ON\x10\x01\"5\n\nHornonType\x12\x13\n\x0fHORNON_TURN_OFF\x10\x00\x12\x12\n\x0eHORNON_TURN_ON\x10\x01\"S\n\x14\x46windshieldwiperType\x12\x1d\n\x19\x46WINDSHIELDWIPER_TURN_OFF\x10\x00\x12\x1c\n\x18\x46WINDSHIELDWIPER_TURN_ON\x10\x01\"S\n\x14RwindshieldwiperType\x12\x1d\n\x19RWINDSHIELDWIPER_TURN_OFF\x10\x00\x12\x1c\n\x18RWINDSHIELDWIPER_TURN_ON\x10\x01\"\xa3\x05\n\x03Wey\x12\x37\n\x0f\x61\x64s_shifter_115\x18\x01 \x01(\x0b\x32\x1e.apollo.canbus.Ads_shifter_115\x12/\n\x0b\x61\x64s_eps_113\x18\x02 \x01(\x0b\x32\x1a.apollo.canbus.Ads_eps_113\x12-\n\nstatus_310\x18\x03 \x01(\x0b\x32\x19.apollo.canbus.Status_310\x12\x33\n\rvin_resp3_393\x18\x04 \x01(\x0b\x32\x1c.apollo.canbus.Vin_resp3_393\x12\x33\n\rvin_resp2_392\x18\x05 \x01(\x0b\x32\x1c.apollo.canbus.Vin_resp2_392\x12\x33\n\rvin_resp1_391\x18\x06 \x01(\x0b\x32\x1c.apollo.canbus.Vin_resp1_391\x12\x37\n\x0f\x61\x64s_req_vin_390\x18\x07 \x01(\x0b\x32\x1e.apollo.canbus.Ads_req_vin_390\x12)\n\x08\x61\x64s1_111\x18\x08 \x01(\x0b\x32\x17.apollo.canbus.Ads1_111\x12)\n\x08\x66\x62s2_240\x18\t \x01(\x0b\x32\x17.apollo.canbus.Fbs2_240\x12)\n\x08\x66\x62s1_243\x18\n \x01(\x0b\x32\x17.apollo.canbus.Fbs1_243\x12)\n\x08\x66\x62s4_235\x18\x0b \x01(\x0b\x32\x17.apollo.canbus.Fbs4_235\x12)\n\x08\x66\x61il_241\x18\x0c \x01(\x0b\x32\x17.apollo.canbus.Fail_241\x12)\n\x08\x66\x62s3_237\x18\r \x01(\x0b\x32\x17.apollo.canbus.Fbs3_237\x12)\n\x08\x61\x64s3_38e\x18\x0e \x01(\x0b\x32\x17.apollo.canbus.Ads3_38e'
)



_ADS_SHIFTER_115_ADS_SHIFTMODETYPE = _descriptor.EnumDescriptor(
  name='Ads_shiftmodeType',
  full_name='apollo.canbus.Ads_shifter_115.Ads_shiftmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_SHIFTMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_SHIFTMODE_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=217,
  serialized_end=288,
)
_sym_db.RegisterEnumDescriptor(_ADS_SHIFTER_115_ADS_SHIFTMODETYPE)

_ADS_SHIFTER_115_ADS_TARGETGEARTYPE = _descriptor.EnumDescriptor(
  name='Ads_targetgearType',
  full_name='apollo.canbus.Ads_shifter_115.Ads_targetgearType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_TARGETGEAR_N', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_TARGETGEAR_R', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_TARGETGEAR_P', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_TARGETGEAR_D', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=290,
  serialized_end=398,
)
_sym_db.RegisterEnumDescriptor(_ADS_SHIFTER_115_ADS_TARGETGEARTYPE)

_ADS_EPS_113_ADS_EPSMODETYPE = _descriptor.EnumDescriptor(
  name='Ads_epsmodeType',
  full_name='apollo.canbus.Ads_eps_113.Ads_epsmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_EPSMODE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_EPSMODE_ACTIVE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=512,
  serialized_end=578,
)
_sym_db.RegisterEnumDescriptor(_ADS_EPS_113_ADS_EPSMODETYPE)

_STATUS_310_LONGITUDEACCVALIDTYPE = _descriptor.EnumDescriptor(
  name='LongitudeaccvalidType',
  full_name='apollo.canbus.Status_310.LongitudeaccvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEACCVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEACCVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3027,
  serialized_end=3110,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_LONGITUDEACCVALIDTYPE)

_STATUS_310_LATERALACCEVALIDTYPE = _descriptor.EnumDescriptor(
  name='LateralaccevalidType',
  full_name='apollo.canbus.Status_310.LateralaccevalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LATERALACCEVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LATERALACCEVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3112,
  serialized_end=3192,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_LATERALACCEVALIDTYPE)

_STATUS_310_VEHDYNYAWRATEVALIDTYPE = _descriptor.EnumDescriptor(
  name='VehdynyawratevalidType',
  full_name='apollo.canbus.Status_310.VehdynyawratevalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHDYNYAWRATEVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHDYNYAWRATEVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3194,
  serialized_end=3280,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_VEHDYNYAWRATEVALIDTYPE)

_STATUS_310_FLWHEELSPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='FlwheelspdvalidType',
  full_name='apollo.canbus.Status_310.FlwheelspdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLWHEELSPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLWHEELSPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3282,
  serialized_end=3359,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_FLWHEELSPDVALIDTYPE)

_STATUS_310_FRWHEELSPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='FrwheelspdvalidType',
  full_name='apollo.canbus.Status_310.FrwheelspdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRWHEELSPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRWHEELSPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3361,
  serialized_end=3438,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_FRWHEELSPDVALIDTYPE)

_STATUS_310_RLWHEELSPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='RlwheelspdvalidType',
  full_name='apollo.canbus.Status_310.RlwheelspdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RLWHEELSPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLWHEELSPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3440,
  serialized_end=3517,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_RLWHEELSPDVALIDTYPE)

_STATUS_310_RRWHEELSPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='RrwheelspdvalidType',
  full_name='apollo.canbus.Status_310.RrwheelspdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RRWHEELSPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RRWHEELSPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3519,
  serialized_end=3596,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_RRWHEELSPDVALIDTYPE)

_STATUS_310_VEHICLESPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='VehiclespdvalidType',
  full_name='apollo.canbus.Status_310.VehiclespdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLESPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLESPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3598,
  serialized_end=3675,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_VEHICLESPDVALIDTYPE)

_STATUS_310_LONGITUDEDRIVINGMODETYPE = _descriptor.EnumDescriptor(
  name='LongitudedrivingmodeType',
  full_name='apollo.canbus.Status_310.LongitudedrivingmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEDRIVINGMODE_MANUALMODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEDRIVINGMODE_AUTOMATICSTANDBY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEDRIVINGMODE_AUTOMATICACCELERATION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LONGITUDEDRIVINGMODE_AUTOMATICDECELERATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3678,
  serialized_end=3880,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_LONGITUDEDRIVINGMODETYPE)

_STATUS_310_ENGSPDVALIDTYPE = _descriptor.EnumDescriptor(
  name='EngspdvalidType',
  full_name='apollo.canbus.Status_310.EngspdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENGSPDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGSPDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGSPDVALID_INIT_VALUE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGSPDVALID_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3882,
  serialized_end=4001,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_ENGSPDVALIDTYPE)

_STATUS_310_ACCEPEDALOVERRIDETYPE = _descriptor.EnumDescriptor(
  name='AccepedaloverrideType',
  full_name='apollo.canbus.Status_310.AccepedaloverrideType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACCEPEDALOVERRIDE_NOT_OVERRIDE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPEDALOVERRIDE_OVERRIDE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4003,
  serialized_end=4094,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_ACCEPEDALOVERRIDETYPE)

_STATUS_310_BRAKEPEDALSTATUSTYPE = _descriptor.EnumDescriptor(
  name='BrakepedalstatusType',
  full_name='apollo.canbus.Status_310.BrakepedalstatusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKEPEDALSTATUS_NOT_PRESSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKEPEDALSTATUS_PRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKEPEDALSTATUS_RESERVED1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKEPEDALSTATUS_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4097,
  serialized_end=4243,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_BRAKEPEDALSTATUSTYPE)

_STATUS_310_ESPBRAKELIGHTSTSTYPE = _descriptor.EnumDescriptor(
  name='EspbrakelightstsType',
  full_name='apollo.canbus.Status_310.EspbrakelightstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ESPBRAKELIGHTSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESPBRAKELIGHTSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4245,
  serialized_end=4318,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_ESPBRAKELIGHTSTSTYPE)

_STATUS_310_EPBSWTPOSITIONVALIDTYPE = _descriptor.EnumDescriptor(
  name='EpbswtpositionvalidType',
  full_name='apollo.canbus.Status_310.EpbswtpositionvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPBSWTPOSITIONVALID_VALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSWTPOSITIONVALID_NOT_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4320,
  serialized_end=4411,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPBSWTPOSITIONVALIDTYPE)

_STATUS_310_EPBSTSTYPE = _descriptor.EnumDescriptor(
  name='EpbstsType',
  full_name='apollo.canbus.Status_310.EpbstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPBSTS_RELEASED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSTS_CLOSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSTS_IN_PROGRESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSTS_UNKNOWN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4413,
  serialized_end=4509,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPBSTSTYPE)

_STATUS_310_CURRENTGEARVALIDTYPE = _descriptor.EnumDescriptor(
  name='CurrentgearvalidType',
  full_name='apollo.canbus.Status_310.CurrentgearvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEARVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEARVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4511,
  serialized_end=4591,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_CURRENTGEARVALIDTYPE)

_STATUS_310_EPSTRQSNSRSTSTYPE = _descriptor.EnumDescriptor(
  name='EpstrqsnsrstsType',
  full_name='apollo.canbus.Status_310.EpstrqsnsrstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPSTRQSNSRSTS_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSTRQSNSRSTS_ABNORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4593,
  serialized_end=4666,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPSTRQSNSRSTSTYPE)

_STATUS_310_EPS_INTERFERDETDVALIDTYPE = _descriptor.EnumDescriptor(
  name='Eps_interferdetdvalidType',
  full_name='apollo.canbus.Status_310.Eps_interferdetdvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_INTERFERDETDVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_INTERFERDETDVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4668,
  serialized_end=4763,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPS_INTERFERDETDVALIDTYPE)

_STATUS_310_EPSHANDSDETNSTSTYPE = _descriptor.EnumDescriptor(
  name='EpshandsdetnstsType',
  full_name='apollo.canbus.Status_310.EpshandsdetnstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPSHANDSDETNSTS_HANDSOFF_NOT_DETECTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSHANDSDETNSTS_HANDOFFF_DETECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4765,
  serialized_end=4868,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPSHANDSDETNSTSTYPE)

_STATUS_310_EPS_HANDSDETNSTSVALIDTYPE = _descriptor.EnumDescriptor(
  name='Eps_handsdetnstsvalidType',
  full_name='apollo.canbus.Status_310.Eps_handsdetnstsvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_HANDSDETNSTSVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_HANDSDETNSTSVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4870,
  serialized_end=4965,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_EPS_HANDSDETNSTSVALIDTYPE)

_STATUS_310_STEERWHEELANGLESIGNTYPE = _descriptor.EnumDescriptor(
  name='SteerwheelanglesignType',
  full_name='apollo.canbus.Status_310.SteerwheelanglesignType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERWHEELANGLESIGN_LEFT_POSITIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERWHEELANGLESIGN_RIGHT_NEGATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4967,
  serialized_end=5071,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_STEERWHEELANGLESIGNTYPE)

_STATUS_310_STEERWHEELSPDSIGNTYPE = _descriptor.EnumDescriptor(
  name='SteerwheelspdsignType',
  full_name='apollo.canbus.Status_310.SteerwheelspdsignType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEERWHEELSPDSIGN_LEFT_POSITIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEERWHEELSPDSIGN_RIGHT_NEGATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5073,
  serialized_end=5171,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_STEERWHEELSPDSIGNTYPE)

_STATUS_310_DRIVERDOORSTSTYPE = _descriptor.EnumDescriptor(
  name='DriverdoorstsType',
  full_name='apollo.canbus.Status_310.DriverdoorstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRIVERDOORSTS_CLOSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVERDOORSTS_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5173,
  serialized_end=5242,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_DRIVERDOORSTSTYPE)

_STATUS_310_RLDOORSTSTYPE = _descriptor.EnumDescriptor(
  name='RldoorstsType',
  full_name='apollo.canbus.Status_310.RldoorstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RLDOORSTS_CLOSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLDOORSTS_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5244,
  serialized_end=5301,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_RLDOORSTSTYPE)

_STATUS_310_PASSENGERDOORSTSTYPE = _descriptor.EnumDescriptor(
  name='PassengerdoorstsType',
  full_name='apollo.canbus.Status_310.PassengerdoorstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PASSENGERDOORSTS_CLOSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSENGERDOORSTS_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5303,
  serialized_end=5381,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_PASSENGERDOORSTSTYPE)

_STATUS_310_RRDOORSTSTYPE = _descriptor.EnumDescriptor(
  name='RrdoorstsType',
  full_name='apollo.canbus.Status_310.RrdoorstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RRDOORSTS_CLOSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RRDOORSTS_OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5383,
  serialized_end=5440,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_RRDOORSTSTYPE)

_STATUS_310_FRONTFOGLMPSTSTYPE = _descriptor.EnumDescriptor(
  name='FrontfoglmpstsType',
  full_name='apollo.canbus.Status_310.FrontfoglmpstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRONTFOGLMPSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONTFOGLMPSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONTFOGLMPSTS_RESERVED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONTFOGLMPSTS_NOT_AVAILABLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5443,
  serialized_end=5573,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_FRONTFOGLMPSTSTYPE)

_STATUS_310_REARFOGLMPSTSTYPE = _descriptor.EnumDescriptor(
  name='RearfoglmpstsType',
  full_name='apollo.canbus.Status_310.RearfoglmpstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REARFOGLMPSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REARFOGLMPSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5575,
  serialized_end=5639,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_REARFOGLMPSTSTYPE)

_STATUS_310_LOWBEAMSTSTYPE = _descriptor.EnumDescriptor(
  name='LowbeamstsType',
  full_name='apollo.canbus.Status_310.LowbeamstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOWBEAMSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOWBEAMSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5641,
  serialized_end=5696,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_LOWBEAMSTSTYPE)

_STATUS_310_HIGHBEAMSTSTYPE = _descriptor.EnumDescriptor(
  name='HighbeamstsType',
  full_name='apollo.canbus.Status_310.HighbeamstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HIGHBEAMSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHBEAMSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5698,
  serialized_end=5756,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_HIGHBEAMSTSTYPE)

_STATUS_310_LEFTTURNLAMPSTSTYPE = _descriptor.EnumDescriptor(
  name='LeftturnlampstsType',
  full_name='apollo.canbus.Status_310.LeftturnlampstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFTTURNLAMPSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFTTURNLAMPSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5758,
  serialized_end=5828,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_LEFTTURNLAMPSTSTYPE)

_STATUS_310_RIGHTTURNLAMPSTSTYPE = _descriptor.EnumDescriptor(
  name='RightturnlampstsType',
  full_name='apollo.canbus.Status_310.RightturnlampstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RIGHTTURNLAMPSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHTTURNLAMPSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5830,
  serialized_end=5903,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_RIGHTTURNLAMPSTSTYPE)

_STATUS_310_BCM_AVAILSTSTYPE = _descriptor.EnumDescriptor(
  name='Bcm_availstsType',
  full_name='apollo.canbus.Status_310.Bcm_availstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_AVAILSTS_MANUAL_MODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_AVAILSTS_AUTONOMOUS_MODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_AVAILSTS_RESERVED1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_AVAILSTS_RESERVED2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5906,
  serialized_end=6044,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_BCM_AVAILSTSTYPE)

_STATUS_310_BRAKELMPSTSTYPE = _descriptor.EnumDescriptor(
  name='BrakelmpstsType',
  full_name='apollo.canbus.Status_310.BrakelmpstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKELMPSTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKELMPSTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6046,
  serialized_end=6104,
)
_sym_db.RegisterEnumDescriptor(_STATUS_310_BRAKELMPSTSTYPE)

_ADS_REQ_VIN_390_REQ_VIN_SIGNALTYPE = _descriptor.EnumDescriptor(
  name='Req_vin_signalType',
  full_name='apollo.canbus.Ads_req_vin_390.Req_vin_signalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQ_VIN_SIGNAL_NO_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REQ_VIN_SIGNAL_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6509,
  serialized_end=6588,
)
_sym_db.RegisterEnumDescriptor(_ADS_REQ_VIN_390_REQ_VIN_SIGNALTYPE)

_ADS1_111_ADS_DECTOSTOPTYPE = _descriptor.EnumDescriptor(
  name='Ads_dectostopType',
  full_name='apollo.canbus.Ads1_111.Ads_dectostopType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_DECTOSTOP_NO_DEMAND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_DECTOSTOP_DEMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6923,
  serialized_end=6997,
)
_sym_db.RegisterEnumDescriptor(_ADS1_111_ADS_DECTOSTOPTYPE)

_ADS1_111_ADS_MODETYPE = _descriptor.EnumDescriptor(
  name='Ads_modeType',
  full_name='apollo.canbus.Ads1_111.Ads_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_MODE_OFF_MODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_MODE_ACTIVE_MODE', index=1, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6999,
  serialized_end=7062,
)
_sym_db.RegisterEnumDescriptor(_ADS1_111_ADS_MODETYPE)

_ADS1_111_ADS_DRIVEOFF_REQTYPE = _descriptor.EnumDescriptor(
  name='Ads_driveoff_reqType',
  full_name='apollo.canbus.Ads1_111.Ads_driveoff_reqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_DRIVEOFF_REQ_NO_DEMAND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_DRIVEOFF_REQ_DEMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7064,
  serialized_end=7147,
)
_sym_db.RegisterEnumDescriptor(_ADS1_111_ADS_DRIVEOFF_REQTYPE)

_ADS1_111_ADS_AEB_TGTDECEL_REQTYPE = _descriptor.EnumDescriptor(
  name='Ads_aeb_tgtdecel_reqType',
  full_name='apollo.canbus.Ads1_111.Ads_aeb_tgtdecel_reqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_AEB_TGTDECEL_REQ_NO_DEMAND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_AEB_TGTDECEL_REQ_DEMAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7149,
  serialized_end=7244,
)
_sym_db.RegisterEnumDescriptor(_ADS1_111_ADS_AEB_TGTDECEL_REQTYPE)

_FBS2_240_FLWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='FlwheeldirectionType',
  full_name='apollo.canbus.Fbs2_240.FlwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLWHEELDIRECTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLWHEELDIRECTION_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLWHEELDIRECTION_BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLWHEELDIRECTION_STOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7566,
  serialized_end=7706,
)
_sym_db.RegisterEnumDescriptor(_FBS2_240_FLWHEELDIRECTIONTYPE)

_FBS2_240_RLWHEELDRIVEDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='RlwheeldrivedirectionType',
  full_name='apollo.canbus.Fbs2_240.RlwheeldrivedirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RLWHEELDRIVEDIRECTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLWHEELDRIVEDIRECTION_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLWHEELDRIVEDIRECTION_BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLWHEELDRIVEDIRECTION_STOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7709,
  serialized_end=7874,
)
_sym_db.RegisterEnumDescriptor(_FBS2_240_RLWHEELDRIVEDIRECTIONTYPE)

_FBS2_240_RRWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='RrwheeldirectionType',
  full_name='apollo.canbus.Fbs2_240.RrwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RRWHEELDIRECTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RRWHEELDIRECTION_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RRWHEELDIRECTION_BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RRWHEELDIRECTION_STOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7877,
  serialized_end=8017,
)
_sym_db.RegisterEnumDescriptor(_FBS2_240_RRWHEELDIRECTIONTYPE)

_FBS1_243_FRWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='FrwheeldirectionType',
  full_name='apollo.canbus.Fbs1_243.FrwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRWHEELDIRECTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRWHEELDIRECTION_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRWHEELDIRECTION_BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRWHEELDIRECTION_STOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8192,
  serialized_end=8332,
)
_sym_db.RegisterEnumDescriptor(_FBS1_243_FRWHEELDIRECTIONTYPE)

_FAIL_241_ENGFAILTYPE = _descriptor.EnumDescriptor(
  name='EngfailType',
  full_name='apollo.canbus.Fail_241.EngfailType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENGFAIL_NO_FAIL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGFAIL_FAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8681,
  serialized_end=8733,
)
_sym_db.RegisterEnumDescriptor(_FAIL_241_ENGFAILTYPE)

_FAIL_241_ESPFAILTYPE = _descriptor.EnumDescriptor(
  name='EspfailType',
  full_name='apollo.canbus.Fail_241.EspfailType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ESPFAIL_NO_FAILURE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESPFAIL_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8735,
  serialized_end=8793,
)
_sym_db.RegisterEnumDescriptor(_FAIL_241_ESPFAILTYPE)

_FAIL_241_EPBFAILTYPE = _descriptor.EnumDescriptor(
  name='EpbfailType',
  full_name='apollo.canbus.Fail_241.EpbfailType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPBFAIL_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBFAIL_NO_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBFAIL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBFAIL_DIAGNOSIS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8795,
  serialized_end=8895,
)
_sym_db.RegisterEnumDescriptor(_FAIL_241_EPBFAILTYPE)

_FAIL_241_SHIFTFAILTYPE = _descriptor.EnumDescriptor(
  name='ShiftfailType',
  full_name='apollo.canbus.Fail_241.ShiftfailType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_NO_FAIL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_TRANSMISSION_MALFUNCTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_TRANSMISSION_P_ENGAGEMENT_FAULT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_TRANSMISSION_P_DISENGAGEMENT_FAULT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_RESERVED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHIFTFAIL_TRANSMISSION_LIMIT_FUNCTION', index=5, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8898,
  serialized_end=9140,
)
_sym_db.RegisterEnumDescriptor(_FAIL_241_SHIFTFAILTYPE)

_FAIL_241_EPSFAILTYPE = _descriptor.EnumDescriptor(
  name='EpsfailType',
  full_name='apollo.canbus.Fail_241.EpsfailType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPSFAIL_NO_FAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSFAIL_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9142,
  serialized_end=9196,
)
_sym_db.RegisterEnumDescriptor(_FAIL_241_EPSFAILTYPE)

_FBS3_237_EPBSWTICHPOSITIONTYPE = _descriptor.EnumDescriptor(
  name='EpbswtichpositionType',
  full_name='apollo.canbus.Fbs3_237.EpbswtichpositionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPBSWTICHPOSITION_NEUTRAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSWTICHPOSITION_RELEASE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSWTICHPOSITION_APPLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPBSWTICHPOSITION_RESERVED1', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9576,
  serialized_end=9723,
)
_sym_db.RegisterEnumDescriptor(_FBS3_237_EPBSWTICHPOSITIONTYPE)

_FBS3_237_CURRENTGEARTYPE = _descriptor.EnumDescriptor(
  name='CurrentgearType',
  full_name='apollo.canbus.Fbs3_237.CurrentgearType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEAR_P', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEAR_R', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEAR_N', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURRENTGEAR_D', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9725,
  serialized_end=9818,
)
_sym_db.RegisterEnumDescriptor(_FBS3_237_CURRENTGEARTYPE)

_FBS3_237_EPS_STREEINGMODETYPE = _descriptor.EnumDescriptor(
  name='Eps_streeingmodeType',
  full_name='apollo.canbus.Fbs3_237.Eps_streeingmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_MANUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_AUTOMATIC_AVAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_MANUAL_FROM_DRVNTERFERENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_MANUAL_FROM_EPS_FAILED_DETECTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_TEMPORARY_INHIBITED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_RESERVED1', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_RESERVED2', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_STREEINGMODE_RESERVED3', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9821,
  serialized_end=10151,
)
_sym_db.RegisterEnumDescriptor(_FBS3_237_EPS_STREEINGMODETYPE)

_FBS3_237_EPSCURRMODTYPE = _descriptor.EnumDescriptor(
  name='EpscurrmodType',
  full_name='apollo.canbus.Fbs3_237.EpscurrmodType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_NORMAL_MODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_SPORT_MODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_COMFORT_MODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_MODESELECTIONNOTPOSSIBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_NO_DISPLAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_CONDITIONNOTMEET', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPSCURRMOD_RESERVED1', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10154,
  serialized_end=10381,
)
_sym_db.RegisterEnumDescriptor(_FBS3_237_EPSCURRMODTYPE)

_ADS3_38E_ADS_BCM_WORKSTSTYPE = _descriptor.EnumDescriptor(
  name='Ads_bcm_workstsType',
  full_name='apollo.canbus.Ads3_38e.Ads_bcm_workstsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_BCM_WORKSTS_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_BCM_WORKSTS_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_BCM_WORKSTS_ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_BCM_WORKSTS_FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11257,
  serialized_end=11391,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_ADS_BCM_WORKSTSTYPE)

_ADS3_38E_ADS_BCMWORKSTSVALIDTYPE = _descriptor.EnumDescriptor(
  name='Ads_bcmworkstsvalidType',
  full_name='apollo.canbus.Ads3_38e.Ads_bcmworkstsvalidType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_BCMWORKSTSVALID_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_BCMWORKSTSVALID_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11393,
  serialized_end=11482,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_ADS_BCMWORKSTSVALIDTYPE)

_ADS3_38E_ADS_REQCONTROLBCMTYPE = _descriptor.EnumDescriptor(
  name='Ads_reqcontrolbcmType',
  full_name='apollo.canbus.Ads3_38e.Ads_reqcontrolbcmType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADS_REQCONTROLBCM_NO_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADS_REQCONTROLBCM_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11484,
  serialized_end=11572,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_ADS_REQCONTROLBCMTYPE)

_ADS3_38E_HIGHBEAMTONTYPE = _descriptor.EnumDescriptor(
  name='HighbeamtonType',
  full_name='apollo.canbus.Ads3_38e.HighbeamtonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HIGHBEAMTON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHBEAMTON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11574,
  serialized_end=11642,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_HIGHBEAMTONTYPE)

_ADS3_38E_DIPPEDBEAMONTYPE = _descriptor.EnumDescriptor(
  name='DippedbeamonType',
  full_name='apollo.canbus.Ads3_38e.DippedbeamonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DIPPEDBEAMON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIPPEDBEAMON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11644,
  serialized_end=11715,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_DIPPEDBEAMONTYPE)

_ADS3_38E_TURNLLIGHTONTYPE = _descriptor.EnumDescriptor(
  name='TurnllightonType',
  full_name='apollo.canbus.Ads3_38e.TurnllightonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURNLLIGHTON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURNLLIGHTON_TURN_LEFT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURNLLIGHTON_TURN_RIGHT_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURNLLIGHTON_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11718,
  serialized_end=11853,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_TURNLLIGHTONTYPE)

_ADS3_38E_EMERGENCYLIGHTONTYPE = _descriptor.EnumDescriptor(
  name='EmergencylightonType',
  full_name='apollo.canbus.Ads3_38e.EmergencylightonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMERGENCYLIGHTON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCYLIGHTON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11855,
  serialized_end=11938,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_EMERGENCYLIGHTONTYPE)

_ADS3_38E_FFOGLAMPONTYPE = _descriptor.EnumDescriptor(
  name='FfoglamponType',
  full_name='apollo.canbus.Ads3_38e.FfoglamponType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FFOGLAMPON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FFOGLAMPON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11940,
  serialized_end=12005,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_FFOGLAMPONTYPE)

_ADS3_38E_RFOGLAMPONTYPE = _descriptor.EnumDescriptor(
  name='RfoglamponType',
  full_name='apollo.canbus.Ads3_38e.RfoglamponType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RFOGLAMPON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RFOGLAMPON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12007,
  serialized_end=12072,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_RFOGLAMPONTYPE)

_ADS3_38E_BRAKELIGHTTYPE = _descriptor.EnumDescriptor(
  name='BrakelightType',
  full_name='apollo.canbus.Ads3_38e.BrakelightType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BRAKELIGHT_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKELIGHT_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12074,
  serialized_end=12139,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_BRAKELIGHTTYPE)

_ADS3_38E_HORNONTYPE = _descriptor.EnumDescriptor(
  name='HornonType',
  full_name='apollo.canbus.Ads3_38e.HornonType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HORNON_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HORNON_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12141,
  serialized_end=12194,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_HORNONTYPE)

_ADS3_38E_FWINDSHIELDWIPERTYPE = _descriptor.EnumDescriptor(
  name='FwindshieldwiperType',
  full_name='apollo.canbus.Ads3_38e.FwindshieldwiperType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FWINDSHIELDWIPER_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FWINDSHIELDWIPER_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12196,
  serialized_end=12279,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_FWINDSHIELDWIPERTYPE)

_ADS3_38E_RWINDSHIELDWIPERTYPE = _descriptor.EnumDescriptor(
  name='RwindshieldwiperType',
  full_name='apollo.canbus.Ads3_38e.RwindshieldwiperType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RWINDSHIELDWIPER_TURN_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RWINDSHIELDWIPER_TURN_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12281,
  serialized_end=12364,
)
_sym_db.RegisterEnumDescriptor(_ADS3_38E_RWINDSHIELDWIPERTYPE)


_ADS_SHIFTER_115 = _descriptor.Descriptor(
  name='Ads_shifter_115',
  full_name='apollo.canbus.Ads_shifter_115',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ads_shiftmode', full_name='apollo.canbus.Ads_shifter_115.ads_shiftmode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_targetgear', full_name='apollo.canbus.Ads_shifter_115.ads_targetgear', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS_SHIFTER_115_ADS_SHIFTMODETYPE,
    _ADS_SHIFTER_115_ADS_TARGETGEARTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=398,
)


_ADS_EPS_113 = _descriptor.Descriptor(
  name='Ads_eps_113',
  full_name='apollo.canbus.Ads_eps_113',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ads_epsmode', full_name='apollo.canbus.Ads_eps_113.ads_epsmode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_reqepstargetangle', full_name='apollo.canbus.Ads_eps_113.ads_reqepstargetangle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS_EPS_113_ADS_EPSMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=578,
)


_STATUS_310 = _descriptor.Descriptor(
  name='Status_310',
  full_name='apollo.canbus.Status_310',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitudeaccvalid', full_name='apollo.canbus.Status_310.longitudeaccvalid', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateralaccevalid', full_name='apollo.canbus.Status_310.lateralaccevalid', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehdynyawratevalid', full_name='apollo.canbus.Status_310.vehdynyawratevalid', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flwheelspdvalid', full_name='apollo.canbus.Status_310.flwheelspdvalid', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frwheelspdvalid', full_name='apollo.canbus.Status_310.frwheelspdvalid', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rlwheelspdvalid', full_name='apollo.canbus.Status_310.rlwheelspdvalid', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrwheelspdvalid', full_name='apollo.canbus.Status_310.rrwheelspdvalid', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehiclespdvalid', full_name='apollo.canbus.Status_310.vehiclespdvalid', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitudedrivingmode', full_name='apollo.canbus.Status_310.longitudedrivingmode', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engspdvalid', full_name='apollo.canbus.Status_310.engspdvalid', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepedaloverride', full_name='apollo.canbus.Status_310.accepedaloverride', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brakepedalstatus', full_name='apollo.canbus.Status_310.brakepedalstatus', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='espbrakelightsts', full_name='apollo.canbus.Status_310.espbrakelightsts', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epbswtpositionvalid', full_name='apollo.canbus.Status_310.epbswtpositionvalid', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epbsts', full_name='apollo.canbus.Status_310.epbsts', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentgearvalid', full_name='apollo.canbus.Status_310.currentgearvalid', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epstrqsnsrsts', full_name='apollo.canbus.Status_310.epstrqsnsrsts', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_interferdetdvalid', full_name='apollo.canbus.Status_310.eps_interferdetdvalid', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epshandsdetnsts', full_name='apollo.canbus.Status_310.epshandsdetnsts', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_handsdetnstsvalid', full_name='apollo.canbus.Status_310.eps_handsdetnstsvalid', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steerwheelanglesign', full_name='apollo.canbus.Status_310.steerwheelanglesign', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steerwheelspdsign', full_name='apollo.canbus.Status_310.steerwheelspdsign', index=21,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driverdoorsts', full_name='apollo.canbus.Status_310.driverdoorsts', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rldoorsts', full_name='apollo.canbus.Status_310.rldoorsts', index=23,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passengerdoorsts', full_name='apollo.canbus.Status_310.passengerdoorsts', index=24,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrdoorsts', full_name='apollo.canbus.Status_310.rrdoorsts', index=25,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frontfoglmpsts', full_name='apollo.canbus.Status_310.frontfoglmpsts', index=26,
      number=27, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rearfoglmpsts', full_name='apollo.canbus.Status_310.rearfoglmpsts', index=27,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowbeamsts', full_name='apollo.canbus.Status_310.lowbeamsts', index=28,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highbeamsts', full_name='apollo.canbus.Status_310.highbeamsts', index=29,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leftturnlampsts', full_name='apollo.canbus.Status_310.leftturnlampsts', index=30,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rightturnlampsts', full_name='apollo.canbus.Status_310.rightturnlampsts', index=31,
      number=32, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_availsts', full_name='apollo.canbus.Status_310.bcm_availsts', index=32,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brakelmpsts', full_name='apollo.canbus.Status_310.brakelmpsts', index=33,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUS_310_LONGITUDEACCVALIDTYPE,
    _STATUS_310_LATERALACCEVALIDTYPE,
    _STATUS_310_VEHDYNYAWRATEVALIDTYPE,
    _STATUS_310_FLWHEELSPDVALIDTYPE,
    _STATUS_310_FRWHEELSPDVALIDTYPE,
    _STATUS_310_RLWHEELSPDVALIDTYPE,
    _STATUS_310_RRWHEELSPDVALIDTYPE,
    _STATUS_310_VEHICLESPDVALIDTYPE,
    _STATUS_310_LONGITUDEDRIVINGMODETYPE,
    _STATUS_310_ENGSPDVALIDTYPE,
    _STATUS_310_ACCEPEDALOVERRIDETYPE,
    _STATUS_310_BRAKEPEDALSTATUSTYPE,
    _STATUS_310_ESPBRAKELIGHTSTSTYPE,
    _STATUS_310_EPBSWTPOSITIONVALIDTYPE,
    _STATUS_310_EPBSTSTYPE,
    _STATUS_310_CURRENTGEARVALIDTYPE,
    _STATUS_310_EPSTRQSNSRSTSTYPE,
    _STATUS_310_EPS_INTERFERDETDVALIDTYPE,
    _STATUS_310_EPSHANDSDETNSTSTYPE,
    _STATUS_310_EPS_HANDSDETNSTSVALIDTYPE,
    _STATUS_310_STEERWHEELANGLESIGNTYPE,
    _STATUS_310_STEERWHEELSPDSIGNTYPE,
    _STATUS_310_DRIVERDOORSTSTYPE,
    _STATUS_310_RLDOORSTSTYPE,
    _STATUS_310_PASSENGERDOORSTSTYPE,
    _STATUS_310_RRDOORSTSTYPE,
    _STATUS_310_FRONTFOGLMPSTSTYPE,
    _STATUS_310_REARFOGLMPSTSTYPE,
    _STATUS_310_LOWBEAMSTSTYPE,
    _STATUS_310_HIGHBEAMSTSTYPE,
    _STATUS_310_LEFTTURNLAMPSTSTYPE,
    _STATUS_310_RIGHTTURNLAMPSTSTYPE,
    _STATUS_310_BCM_AVAILSTSTYPE,
    _STATUS_310_BRAKELMPSTSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=6104,
)


_VIN_RESP3_393 = _descriptor.Descriptor(
  name='Vin_resp3_393',
  full_name='apollo.canbus.Vin_resp3_393',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin16', full_name='apollo.canbus.Vin_resp3_393.vin16', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6106,
  serialized_end=6136,
)


_VIN_RESP2_392 = _descriptor.Descriptor(
  name='Vin_resp2_392',
  full_name='apollo.canbus.Vin_resp2_392',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin15', full_name='apollo.canbus.Vin_resp2_392.vin15', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin14', full_name='apollo.canbus.Vin_resp2_392.vin14', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin13', full_name='apollo.canbus.Vin_resp2_392.vin13', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin12', full_name='apollo.canbus.Vin_resp2_392.vin12', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin11', full_name='apollo.canbus.Vin_resp2_392.vin11', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin10', full_name='apollo.canbus.Vin_resp2_392.vin10', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin09', full_name='apollo.canbus.Vin_resp2_392.vin09', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin08', full_name='apollo.canbus.Vin_resp2_392.vin08', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6139,
  serialized_end=6274,
)


_VIN_RESP1_391 = _descriptor.Descriptor(
  name='Vin_resp1_391',
  full_name='apollo.canbus.Vin_resp1_391',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin07', full_name='apollo.canbus.Vin_resp1_391.vin07', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin06', full_name='apollo.canbus.Vin_resp1_391.vin06', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin05', full_name='apollo.canbus.Vin_resp1_391.vin05', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin04', full_name='apollo.canbus.Vin_resp1_391.vin04', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin03', full_name='apollo.canbus.Vin_resp1_391.vin03', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin02', full_name='apollo.canbus.Vin_resp1_391.vin02', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin00', full_name='apollo.canbus.Vin_resp1_391.vin00', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin01', full_name='apollo.canbus.Vin_resp1_391.vin01', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6277,
  serialized_end=6412,
)


_ADS_REQ_VIN_390 = _descriptor.Descriptor(
  name='Ads_req_vin_390',
  full_name='apollo.canbus.Ads_req_vin_390',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_vin_signal', full_name='apollo.canbus.Ads_req_vin_390.req_vin_signal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS_REQ_VIN_390_REQ_VIN_SIGNALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6415,
  serialized_end=6588,
)


_ADS1_111 = _descriptor.Descriptor(
  name='Ads1_111',
  full_name='apollo.canbus.Ads1_111',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ads_dectostop', full_name='apollo.canbus.Ads1_111.ads_dectostop', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_mode', full_name='apollo.canbus.Ads1_111.ads_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_taracce', full_name='apollo.canbus.Ads1_111.ads_taracce', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_driveoff_req', full_name='apollo.canbus.Ads1_111.ads_driveoff_req', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_aeb_taracce', full_name='apollo.canbus.Ads1_111.ads_aeb_taracce', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_aeb_tgtdecel_req', full_name='apollo.canbus.Ads1_111.ads_aeb_tgtdecel_req', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS1_111_ADS_DECTOSTOPTYPE,
    _ADS1_111_ADS_MODETYPE,
    _ADS1_111_ADS_DRIVEOFF_REQTYPE,
    _ADS1_111_ADS_AEB_TGTDECEL_REQTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6591,
  serialized_end=7244,
)


_FBS2_240 = _descriptor.Descriptor(
  name='Fbs2_240',
  full_name='apollo.canbus.Fbs2_240',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flwheeldirection', full_name='apollo.canbus.Fbs2_240.flwheeldirection', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frwheelspd', full_name='apollo.canbus.Fbs2_240.frwheelspd', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rlwheeldrivedirection', full_name='apollo.canbus.Fbs2_240.rlwheeldrivedirection', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rlwheelspd', full_name='apollo.canbus.Fbs2_240.rlwheelspd', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrwheeldirection', full_name='apollo.canbus.Fbs2_240.rrwheeldirection', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrwheelspd', full_name='apollo.canbus.Fbs2_240.rrwheelspd', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehiclespd', full_name='apollo.canbus.Fbs2_240.vehiclespd', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FBS2_240_FLWHEELDIRECTIONTYPE,
    _FBS2_240_RLWHEELDRIVEDIRECTIONTYPE,
    _FBS2_240_RRWHEELDIRECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7247,
  serialized_end=8017,
)


_FBS1_243 = _descriptor.Descriptor(
  name='Fbs1_243',
  full_name='apollo.canbus.Fbs1_243',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitudeacce', full_name='apollo.canbus.Fbs1_243.longitudeacce', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateralacce', full_name='apollo.canbus.Fbs1_243.lateralacce', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehdynyawrate', full_name='apollo.canbus.Fbs1_243.vehdynyawrate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flwheelspd', full_name='apollo.canbus.Fbs1_243.flwheelspd', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frwheeldirection', full_name='apollo.canbus.Fbs1_243.frwheeldirection', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FBS1_243_FRWHEELDIRECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8020,
  serialized_end=8332,
)


_FBS4_235 = _descriptor.Descriptor(
  name='Fbs4_235',
  full_name='apollo.canbus.Fbs4_235',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steerwheelangle', full_name='apollo.canbus.Fbs4_235.steerwheelangle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steerwheelspd', full_name='apollo.canbus.Fbs4_235.steerwheelspd', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8334,
  serialized_end=8392,
)


_FAIL_241 = _descriptor.Descriptor(
  name='Fail_241',
  full_name='apollo.canbus.Fail_241',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engfail', full_name='apollo.canbus.Fail_241.engfail', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='espfail', full_name='apollo.canbus.Fail_241.espfail', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epbfail', full_name='apollo.canbus.Fail_241.epbfail', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shiftfail', full_name='apollo.canbus.Fail_241.shiftfail', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epsfail', full_name='apollo.canbus.Fail_241.epsfail', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FAIL_241_ENGFAILTYPE,
    _FAIL_241_ESPFAILTYPE,
    _FAIL_241_EPBFAILTYPE,
    _FAIL_241_SHIFTFAILTYPE,
    _FAIL_241_EPSFAILTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8395,
  serialized_end=9196,
)


_FBS3_237 = _descriptor.Descriptor(
  name='Fbs3_237',
  full_name='apollo.canbus.Fbs3_237',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engspd', full_name='apollo.canbus.Fbs3_237.engspd', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accpedalpos', full_name='apollo.canbus.Fbs3_237.accpedalpos', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epbswtichposition', full_name='apollo.canbus.Fbs3_237.epbswtichposition', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentgear', full_name='apollo.canbus.Fbs3_237.currentgear', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_streeingmode', full_name='apollo.canbus.Fbs3_237.eps_streeingmode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epsdrvinputtrqvalue', full_name='apollo.canbus.Fbs3_237.epsdrvinputtrqvalue', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epsconsumedcurrvalue', full_name='apollo.canbus.Fbs3_237.epsconsumedcurrvalue', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epscurrmod', full_name='apollo.canbus.Fbs3_237.epscurrmod', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FBS3_237_EPBSWTICHPOSITIONTYPE,
    _FBS3_237_CURRENTGEARTYPE,
    _FBS3_237_EPS_STREEINGMODETYPE,
    _FBS3_237_EPSCURRMODTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9199,
  serialized_end=10381,
)


_ADS3_38E = _descriptor.Descriptor(
  name='Ads3_38e',
  full_name='apollo.canbus.Ads3_38e',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ads_bcm_worksts', full_name='apollo.canbus.Ads3_38e.ads_bcm_worksts', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_bcmworkstsvalid', full_name='apollo.canbus.Ads3_38e.ads_bcmworkstsvalid', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_reqcontrolbcm', full_name='apollo.canbus.Ads3_38e.ads_reqcontrolbcm', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highbeamton', full_name='apollo.canbus.Ads3_38e.highbeamton', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dippedbeamon', full_name='apollo.canbus.Ads3_38e.dippedbeamon', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnllighton', full_name='apollo.canbus.Ads3_38e.turnllighton', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergencylighton', full_name='apollo.canbus.Ads3_38e.emergencylighton', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ffoglampon', full_name='apollo.canbus.Ads3_38e.ffoglampon', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rfoglampon', full_name='apollo.canbus.Ads3_38e.rfoglampon', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brakelight', full_name='apollo.canbus.Ads3_38e.brakelight', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hornon', full_name='apollo.canbus.Ads3_38e.hornon', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fwindshieldwiper', full_name='apollo.canbus.Ads3_38e.fwindshieldwiper', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rwindshieldwiper', full_name='apollo.canbus.Ads3_38e.rwindshieldwiper', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS3_38E_ADS_BCM_WORKSTSTYPE,
    _ADS3_38E_ADS_BCMWORKSTSVALIDTYPE,
    _ADS3_38E_ADS_REQCONTROLBCMTYPE,
    _ADS3_38E_HIGHBEAMTONTYPE,
    _ADS3_38E_DIPPEDBEAMONTYPE,
    _ADS3_38E_TURNLLIGHTONTYPE,
    _ADS3_38E_EMERGENCYLIGHTONTYPE,
    _ADS3_38E_FFOGLAMPONTYPE,
    _ADS3_38E_RFOGLAMPONTYPE,
    _ADS3_38E_BRAKELIGHTTYPE,
    _ADS3_38E_HORNONTYPE,
    _ADS3_38E_FWINDSHIELDWIPERTYPE,
    _ADS3_38E_RWINDSHIELDWIPERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10384,
  serialized_end=12364,
)


_WEY = _descriptor.Descriptor(
  name='Wey',
  full_name='apollo.canbus.Wey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ads_shifter_115', full_name='apollo.canbus.Wey.ads_shifter_115', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_eps_113', full_name='apollo.canbus.Wey.ads_eps_113', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_310', full_name='apollo.canbus.Wey.status_310', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin_resp3_393', full_name='apollo.canbus.Wey.vin_resp3_393', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin_resp2_392', full_name='apollo.canbus.Wey.vin_resp2_392', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin_resp1_391', full_name='apollo.canbus.Wey.vin_resp1_391', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_req_vin_390', full_name='apollo.canbus.Wey.ads_req_vin_390', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads1_111', full_name='apollo.canbus.Wey.ads1_111', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fbs2_240', full_name='apollo.canbus.Wey.fbs2_240', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fbs1_243', full_name='apollo.canbus.Wey.fbs1_243', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fbs4_235', full_name='apollo.canbus.Wey.fbs4_235', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_241', full_name='apollo.canbus.Wey.fail_241', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fbs3_237', full_name='apollo.canbus.Wey.fbs3_237', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads3_38e', full_name='apollo.canbus.Wey.ads3_38e', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12367,
  serialized_end=13042,
)

_ADS_SHIFTER_115.fields_by_name['ads_shiftmode'].enum_type = _ADS_SHIFTER_115_ADS_SHIFTMODETYPE
_ADS_SHIFTER_115.fields_by_name['ads_targetgear'].enum_type = _ADS_SHIFTER_115_ADS_TARGETGEARTYPE
_ADS_SHIFTER_115_ADS_SHIFTMODETYPE.containing_type = _ADS_SHIFTER_115
_ADS_SHIFTER_115_ADS_TARGETGEARTYPE.containing_type = _ADS_SHIFTER_115
_ADS_EPS_113.fields_by_name['ads_epsmode'].enum_type = _ADS_EPS_113_ADS_EPSMODETYPE
_ADS_EPS_113_ADS_EPSMODETYPE.containing_type = _ADS_EPS_113
_STATUS_310.fields_by_name['longitudeaccvalid'].enum_type = _STATUS_310_LONGITUDEACCVALIDTYPE
_STATUS_310.fields_by_name['lateralaccevalid'].enum_type = _STATUS_310_LATERALACCEVALIDTYPE
_STATUS_310.fields_by_name['vehdynyawratevalid'].enum_type = _STATUS_310_VEHDYNYAWRATEVALIDTYPE
_STATUS_310.fields_by_name['flwheelspdvalid'].enum_type = _STATUS_310_FLWHEELSPDVALIDTYPE
_STATUS_310.fields_by_name['frwheelspdvalid'].enum_type = _STATUS_310_FRWHEELSPDVALIDTYPE
_STATUS_310.fields_by_name['rlwheelspdvalid'].enum_type = _STATUS_310_RLWHEELSPDVALIDTYPE
_STATUS_310.fields_by_name['rrwheelspdvalid'].enum_type = _STATUS_310_RRWHEELSPDVALIDTYPE
_STATUS_310.fields_by_name['vehiclespdvalid'].enum_type = _STATUS_310_VEHICLESPDVALIDTYPE
_STATUS_310.fields_by_name['longitudedrivingmode'].enum_type = _STATUS_310_LONGITUDEDRIVINGMODETYPE
_STATUS_310.fields_by_name['engspdvalid'].enum_type = _STATUS_310_ENGSPDVALIDTYPE
_STATUS_310.fields_by_name['accepedaloverride'].enum_type = _STATUS_310_ACCEPEDALOVERRIDETYPE
_STATUS_310.fields_by_name['brakepedalstatus'].enum_type = _STATUS_310_BRAKEPEDALSTATUSTYPE
_STATUS_310.fields_by_name['espbrakelightsts'].enum_type = _STATUS_310_ESPBRAKELIGHTSTSTYPE
_STATUS_310.fields_by_name['epbswtpositionvalid'].enum_type = _STATUS_310_EPBSWTPOSITIONVALIDTYPE
_STATUS_310.fields_by_name['epbsts'].enum_type = _STATUS_310_EPBSTSTYPE
_STATUS_310.fields_by_name['currentgearvalid'].enum_type = _STATUS_310_CURRENTGEARVALIDTYPE
_STATUS_310.fields_by_name['epstrqsnsrsts'].enum_type = _STATUS_310_EPSTRQSNSRSTSTYPE
_STATUS_310.fields_by_name['eps_interferdetdvalid'].enum_type = _STATUS_310_EPS_INTERFERDETDVALIDTYPE
_STATUS_310.fields_by_name['epshandsdetnsts'].enum_type = _STATUS_310_EPSHANDSDETNSTSTYPE
_STATUS_310.fields_by_name['eps_handsdetnstsvalid'].enum_type = _STATUS_310_EPS_HANDSDETNSTSVALIDTYPE
_STATUS_310.fields_by_name['steerwheelanglesign'].enum_type = _STATUS_310_STEERWHEELANGLESIGNTYPE
_STATUS_310.fields_by_name['steerwheelspdsign'].enum_type = _STATUS_310_STEERWHEELSPDSIGNTYPE
_STATUS_310.fields_by_name['driverdoorsts'].enum_type = _STATUS_310_DRIVERDOORSTSTYPE
_STATUS_310.fields_by_name['rldoorsts'].enum_type = _STATUS_310_RLDOORSTSTYPE
_STATUS_310.fields_by_name['passengerdoorsts'].enum_type = _STATUS_310_PASSENGERDOORSTSTYPE
_STATUS_310.fields_by_name['rrdoorsts'].enum_type = _STATUS_310_RRDOORSTSTYPE
_STATUS_310.fields_by_name['frontfoglmpsts'].enum_type = _STATUS_310_FRONTFOGLMPSTSTYPE
_STATUS_310.fields_by_name['rearfoglmpsts'].enum_type = _STATUS_310_REARFOGLMPSTSTYPE
_STATUS_310.fields_by_name['lowbeamsts'].enum_type = _STATUS_310_LOWBEAMSTSTYPE
_STATUS_310.fields_by_name['highbeamsts'].enum_type = _STATUS_310_HIGHBEAMSTSTYPE
_STATUS_310.fields_by_name['leftturnlampsts'].enum_type = _STATUS_310_LEFTTURNLAMPSTSTYPE
_STATUS_310.fields_by_name['rightturnlampsts'].enum_type = _STATUS_310_RIGHTTURNLAMPSTSTYPE
_STATUS_310.fields_by_name['bcm_availsts'].enum_type = _STATUS_310_BCM_AVAILSTSTYPE
_STATUS_310.fields_by_name['brakelmpsts'].enum_type = _STATUS_310_BRAKELMPSTSTYPE
_STATUS_310_LONGITUDEACCVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_LATERALACCEVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_VEHDYNYAWRATEVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_FLWHEELSPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_FRWHEELSPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_RLWHEELSPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_RRWHEELSPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_VEHICLESPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_LONGITUDEDRIVINGMODETYPE.containing_type = _STATUS_310
_STATUS_310_ENGSPDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_ACCEPEDALOVERRIDETYPE.containing_type = _STATUS_310
_STATUS_310_BRAKEPEDALSTATUSTYPE.containing_type = _STATUS_310
_STATUS_310_ESPBRAKELIGHTSTSTYPE.containing_type = _STATUS_310
_STATUS_310_EPBSWTPOSITIONVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_EPBSTSTYPE.containing_type = _STATUS_310
_STATUS_310_CURRENTGEARVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_EPSTRQSNSRSTSTYPE.containing_type = _STATUS_310
_STATUS_310_EPS_INTERFERDETDVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_EPSHANDSDETNSTSTYPE.containing_type = _STATUS_310
_STATUS_310_EPS_HANDSDETNSTSVALIDTYPE.containing_type = _STATUS_310
_STATUS_310_STEERWHEELANGLESIGNTYPE.containing_type = _STATUS_310
_STATUS_310_STEERWHEELSPDSIGNTYPE.containing_type = _STATUS_310
_STATUS_310_DRIVERDOORSTSTYPE.containing_type = _STATUS_310
_STATUS_310_RLDOORSTSTYPE.containing_type = _STATUS_310
_STATUS_310_PASSENGERDOORSTSTYPE.containing_type = _STATUS_310
_STATUS_310_RRDOORSTSTYPE.containing_type = _STATUS_310
_STATUS_310_FRONTFOGLMPSTSTYPE.containing_type = _STATUS_310
_STATUS_310_REARFOGLMPSTSTYPE.containing_type = _STATUS_310
_STATUS_310_LOWBEAMSTSTYPE.containing_type = _STATUS_310
_STATUS_310_HIGHBEAMSTSTYPE.containing_type = _STATUS_310
_STATUS_310_LEFTTURNLAMPSTSTYPE.containing_type = _STATUS_310
_STATUS_310_RIGHTTURNLAMPSTSTYPE.containing_type = _STATUS_310
_STATUS_310_BCM_AVAILSTSTYPE.containing_type = _STATUS_310
_STATUS_310_BRAKELMPSTSTYPE.containing_type = _STATUS_310
_ADS_REQ_VIN_390.fields_by_name['req_vin_signal'].enum_type = _ADS_REQ_VIN_390_REQ_VIN_SIGNALTYPE
_ADS_REQ_VIN_390_REQ_VIN_SIGNALTYPE.containing_type = _ADS_REQ_VIN_390
_ADS1_111.fields_by_name['ads_dectostop'].enum_type = _ADS1_111_ADS_DECTOSTOPTYPE
_ADS1_111.fields_by_name['ads_mode'].enum_type = _ADS1_111_ADS_MODETYPE
_ADS1_111.fields_by_name['ads_driveoff_req'].enum_type = _ADS1_111_ADS_DRIVEOFF_REQTYPE
_ADS1_111.fields_by_name['ads_aeb_tgtdecel_req'].enum_type = _ADS1_111_ADS_AEB_TGTDECEL_REQTYPE
_ADS1_111_ADS_DECTOSTOPTYPE.containing_type = _ADS1_111
_ADS1_111_ADS_MODETYPE.containing_type = _ADS1_111
_ADS1_111_ADS_DRIVEOFF_REQTYPE.containing_type = _ADS1_111
_ADS1_111_ADS_AEB_TGTDECEL_REQTYPE.containing_type = _ADS1_111
_FBS2_240.fields_by_name['flwheeldirection'].enum_type = _FBS2_240_FLWHEELDIRECTIONTYPE
_FBS2_240.fields_by_name['rlwheeldrivedirection'].enum_type = _FBS2_240_RLWHEELDRIVEDIRECTIONTYPE
_FBS2_240.fields_by_name['rrwheeldirection'].enum_type = _FBS2_240_RRWHEELDIRECTIONTYPE
_FBS2_240_FLWHEELDIRECTIONTYPE.containing_type = _FBS2_240
_FBS2_240_RLWHEELDRIVEDIRECTIONTYPE.containing_type = _FBS2_240
_FBS2_240_RRWHEELDIRECTIONTYPE.containing_type = _FBS2_240
_FBS1_243.fields_by_name['frwheeldirection'].enum_type = _FBS1_243_FRWHEELDIRECTIONTYPE
_FBS1_243_FRWHEELDIRECTIONTYPE.containing_type = _FBS1_243
_FAIL_241.fields_by_name['engfail'].enum_type = _FAIL_241_ENGFAILTYPE
_FAIL_241.fields_by_name['espfail'].enum_type = _FAIL_241_ESPFAILTYPE
_FAIL_241.fields_by_name['epbfail'].enum_type = _FAIL_241_EPBFAILTYPE
_FAIL_241.fields_by_name['shiftfail'].enum_type = _FAIL_241_SHIFTFAILTYPE
_FAIL_241.fields_by_name['epsfail'].enum_type = _FAIL_241_EPSFAILTYPE
_FAIL_241_ENGFAILTYPE.containing_type = _FAIL_241
_FAIL_241_ESPFAILTYPE.containing_type = _FAIL_241
_FAIL_241_EPBFAILTYPE.containing_type = _FAIL_241
_FAIL_241_SHIFTFAILTYPE.containing_type = _FAIL_241
_FAIL_241_EPSFAILTYPE.containing_type = _FAIL_241
_FBS3_237.fields_by_name['epbswtichposition'].enum_type = _FBS3_237_EPBSWTICHPOSITIONTYPE
_FBS3_237.fields_by_name['currentgear'].enum_type = _FBS3_237_CURRENTGEARTYPE
_FBS3_237.fields_by_name['eps_streeingmode'].enum_type = _FBS3_237_EPS_STREEINGMODETYPE
_FBS3_237.fields_by_name['epscurrmod'].enum_type = _FBS3_237_EPSCURRMODTYPE
_FBS3_237_EPBSWTICHPOSITIONTYPE.containing_type = _FBS3_237
_FBS3_237_CURRENTGEARTYPE.containing_type = _FBS3_237
_FBS3_237_EPS_STREEINGMODETYPE.containing_type = _FBS3_237
_FBS3_237_EPSCURRMODTYPE.containing_type = _FBS3_237
_ADS3_38E.fields_by_name['ads_bcm_worksts'].enum_type = _ADS3_38E_ADS_BCM_WORKSTSTYPE
_ADS3_38E.fields_by_name['ads_bcmworkstsvalid'].enum_type = _ADS3_38E_ADS_BCMWORKSTSVALIDTYPE
_ADS3_38E.fields_by_name['ads_reqcontrolbcm'].enum_type = _ADS3_38E_ADS_REQCONTROLBCMTYPE
_ADS3_38E.fields_by_name['highbeamton'].enum_type = _ADS3_38E_HIGHBEAMTONTYPE
_ADS3_38E.fields_by_name['dippedbeamon'].enum_type = _ADS3_38E_DIPPEDBEAMONTYPE
_ADS3_38E.fields_by_name['turnllighton'].enum_type = _ADS3_38E_TURNLLIGHTONTYPE
_ADS3_38E.fields_by_name['emergencylighton'].enum_type = _ADS3_38E_EMERGENCYLIGHTONTYPE
_ADS3_38E.fields_by_name['ffoglampon'].enum_type = _ADS3_38E_FFOGLAMPONTYPE
_ADS3_38E.fields_by_name['rfoglampon'].enum_type = _ADS3_38E_RFOGLAMPONTYPE
_ADS3_38E.fields_by_name['brakelight'].enum_type = _ADS3_38E_BRAKELIGHTTYPE
_ADS3_38E.fields_by_name['hornon'].enum_type = _ADS3_38E_HORNONTYPE
_ADS3_38E.fields_by_name['fwindshieldwiper'].enum_type = _ADS3_38E_FWINDSHIELDWIPERTYPE
_ADS3_38E.fields_by_name['rwindshieldwiper'].enum_type = _ADS3_38E_RWINDSHIELDWIPERTYPE
_ADS3_38E_ADS_BCM_WORKSTSTYPE.containing_type = _ADS3_38E
_ADS3_38E_ADS_BCMWORKSTSVALIDTYPE.containing_type = _ADS3_38E
_ADS3_38E_ADS_REQCONTROLBCMTYPE.containing_type = _ADS3_38E
_ADS3_38E_HIGHBEAMTONTYPE.containing_type = _ADS3_38E
_ADS3_38E_DIPPEDBEAMONTYPE.containing_type = _ADS3_38E
_ADS3_38E_TURNLLIGHTONTYPE.containing_type = _ADS3_38E
_ADS3_38E_EMERGENCYLIGHTONTYPE.containing_type = _ADS3_38E
_ADS3_38E_FFOGLAMPONTYPE.containing_type = _ADS3_38E
_ADS3_38E_RFOGLAMPONTYPE.containing_type = _ADS3_38E
_ADS3_38E_BRAKELIGHTTYPE.containing_type = _ADS3_38E
_ADS3_38E_HORNONTYPE.containing_type = _ADS3_38E
_ADS3_38E_FWINDSHIELDWIPERTYPE.containing_type = _ADS3_38E
_ADS3_38E_RWINDSHIELDWIPERTYPE.containing_type = _ADS3_38E
_WEY.fields_by_name['ads_shifter_115'].message_type = _ADS_SHIFTER_115
_WEY.fields_by_name['ads_eps_113'].message_type = _ADS_EPS_113
_WEY.fields_by_name['status_310'].message_type = _STATUS_310
_WEY.fields_by_name['vin_resp3_393'].message_type = _VIN_RESP3_393
_WEY.fields_by_name['vin_resp2_392'].message_type = _VIN_RESP2_392
_WEY.fields_by_name['vin_resp1_391'].message_type = _VIN_RESP1_391
_WEY.fields_by_name['ads_req_vin_390'].message_type = _ADS_REQ_VIN_390
_WEY.fields_by_name['ads1_111'].message_type = _ADS1_111
_WEY.fields_by_name['fbs2_240'].message_type = _FBS2_240
_WEY.fields_by_name['fbs1_243'].message_type = _FBS1_243
_WEY.fields_by_name['fbs4_235'].message_type = _FBS4_235
_WEY.fields_by_name['fail_241'].message_type = _FAIL_241
_WEY.fields_by_name['fbs3_237'].message_type = _FBS3_237
_WEY.fields_by_name['ads3_38e'].message_type = _ADS3_38E
DESCRIPTOR.message_types_by_name['Ads_shifter_115'] = _ADS_SHIFTER_115
DESCRIPTOR.message_types_by_name['Ads_eps_113'] = _ADS_EPS_113
DESCRIPTOR.message_types_by_name['Status_310'] = _STATUS_310
DESCRIPTOR.message_types_by_name['Vin_resp3_393'] = _VIN_RESP3_393
DESCRIPTOR.message_types_by_name['Vin_resp2_392'] = _VIN_RESP2_392
DESCRIPTOR.message_types_by_name['Vin_resp1_391'] = _VIN_RESP1_391
DESCRIPTOR.message_types_by_name['Ads_req_vin_390'] = _ADS_REQ_VIN_390
DESCRIPTOR.message_types_by_name['Ads1_111'] = _ADS1_111
DESCRIPTOR.message_types_by_name['Fbs2_240'] = _FBS2_240
DESCRIPTOR.message_types_by_name['Fbs1_243'] = _FBS1_243
DESCRIPTOR.message_types_by_name['Fbs4_235'] = _FBS4_235
DESCRIPTOR.message_types_by_name['Fail_241'] = _FAIL_241
DESCRIPTOR.message_types_by_name['Fbs3_237'] = _FBS3_237
DESCRIPTOR.message_types_by_name['Ads3_38e'] = _ADS3_38E
DESCRIPTOR.message_types_by_name['Wey'] = _WEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ads_shifter_115 = _reflection.GeneratedProtocolMessageType('Ads_shifter_115', (_message.Message,), {
  'DESCRIPTOR' : _ADS_SHIFTER_115,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_shifter_115)
  })
_sym_db.RegisterMessage(Ads_shifter_115)

Ads_eps_113 = _reflection.GeneratedProtocolMessageType('Ads_eps_113', (_message.Message,), {
  'DESCRIPTOR' : _ADS_EPS_113,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_eps_113)
  })
_sym_db.RegisterMessage(Ads_eps_113)

Status_310 = _reflection.GeneratedProtocolMessageType('Status_310', (_message.Message,), {
  'DESCRIPTOR' : _STATUS_310,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Status_310)
  })
_sym_db.RegisterMessage(Status_310)

Vin_resp3_393 = _reflection.GeneratedProtocolMessageType('Vin_resp3_393', (_message.Message,), {
  'DESCRIPTOR' : _VIN_RESP3_393,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vin_resp3_393)
  })
_sym_db.RegisterMessage(Vin_resp3_393)

Vin_resp2_392 = _reflection.GeneratedProtocolMessageType('Vin_resp2_392', (_message.Message,), {
  'DESCRIPTOR' : _VIN_RESP2_392,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vin_resp2_392)
  })
_sym_db.RegisterMessage(Vin_resp2_392)

Vin_resp1_391 = _reflection.GeneratedProtocolMessageType('Vin_resp1_391', (_message.Message,), {
  'DESCRIPTOR' : _VIN_RESP1_391,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vin_resp1_391)
  })
_sym_db.RegisterMessage(Vin_resp1_391)

Ads_req_vin_390 = _reflection.GeneratedProtocolMessageType('Ads_req_vin_390', (_message.Message,), {
  'DESCRIPTOR' : _ADS_REQ_VIN_390,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_req_vin_390)
  })
_sym_db.RegisterMessage(Ads_req_vin_390)

Ads1_111 = _reflection.GeneratedProtocolMessageType('Ads1_111', (_message.Message,), {
  'DESCRIPTOR' : _ADS1_111,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads1_111)
  })
_sym_db.RegisterMessage(Ads1_111)

Fbs2_240 = _reflection.GeneratedProtocolMessageType('Fbs2_240', (_message.Message,), {
  'DESCRIPTOR' : _FBS2_240,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Fbs2_240)
  })
_sym_db.RegisterMessage(Fbs2_240)

Fbs1_243 = _reflection.GeneratedProtocolMessageType('Fbs1_243', (_message.Message,), {
  'DESCRIPTOR' : _FBS1_243,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Fbs1_243)
  })
_sym_db.RegisterMessage(Fbs1_243)

Fbs4_235 = _reflection.GeneratedProtocolMessageType('Fbs4_235', (_message.Message,), {
  'DESCRIPTOR' : _FBS4_235,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Fbs4_235)
  })
_sym_db.RegisterMessage(Fbs4_235)

Fail_241 = _reflection.GeneratedProtocolMessageType('Fail_241', (_message.Message,), {
  'DESCRIPTOR' : _FAIL_241,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Fail_241)
  })
_sym_db.RegisterMessage(Fail_241)

Fbs3_237 = _reflection.GeneratedProtocolMessageType('Fbs3_237', (_message.Message,), {
  'DESCRIPTOR' : _FBS3_237,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Fbs3_237)
  })
_sym_db.RegisterMessage(Fbs3_237)

Ads3_38e = _reflection.GeneratedProtocolMessageType('Ads3_38e', (_message.Message,), {
  'DESCRIPTOR' : _ADS3_38E,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads3_38e)
  })
_sym_db.RegisterMessage(Ads3_38e)

Wey = _reflection.GeneratedProtocolMessageType('Wey', (_message.Message,), {
  'DESCRIPTOR' : _WEY,
  '__module__' : 'modules.canbus.proto.wey_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Wey)
  })
_sym_db.RegisterMessage(Wey)


# @@protoc_insertion_point(module_scope)
